Learn R Programming

rpinterest (version 0.3.1)

BoardSpecByID: Get board using its ID

Description

Get information about a pinterest board using the board ID.

Usage

BoardSpecByID(boardID, token)

Arguments

boardID
a character string with a board ID.
token
a character string with an access token generated at https://developers.pinterest.com/tools/access_token/

Value

Always returns a data.frame, with a warning when appropriate.

Details

Takes a board ID and an access token, returns a data.frame.

Examples

Run this code
BoardSpecByID(boardID = "42080646457333782", token = "your_token")

Run the code above in your browser using DataLab