Learn R Programming

rpinterest (version 0.3.1)

BoardSpecByName: Get board using its name

Description

Get information about a pinterest board using the board name.

Usage

BoardSpecByName(user, board, token)

Arguments

user
a character string with an user name.
board
a character string with a board name.
token
a character string with an access token generated at https://developers.pinterest.com/tools/access_token/

Value

Always returns a data.frame, with a warning when appropriate.

Details

Takes a user name, a board name and an access token.

Examples

Run this code
BoardSpecByName(user = "colinfay", board = "blanc-mon-amour", token = "your_token")

Run the code above in your browser using DataLab